import React, { PureComponent } from "react"; /* eslint-disable-line */
import { View, Text, Platform, TouchableOpacity, TouchableNativeFeedback, Keyboard, Dimensions } from 'react-native'; /* eslint-disable-line */
import IconIOS from 'react-native-vector-icons/Ionicons';

const { width, height } = Dimensions.get('window');
export default class Header extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      searchIcon: 'ios-search',
      title: props.title,
      disable: false
    };
  }

  componentWillReceiveProps(nextProps) {
    this.setState({
      title: nextProps.title
    });
  }

  onDisable(value) {
    this.setState({
      disable: value
    });
  }

  setTitle(title) {
    this.setState({
      title
    });
  }

  actionLeft() {
    Keyboard.dismiss();
    if (this.props.actionLeft) {
      this.props.actionLeft();
    }
  }

  getPaddingHeader() {
    if (Platform.OS === 'ios' &&
      !Platform.isPad &&
      !Platform.isTVOS &&
      (height === 812 || width === 812)) {
      return 32;
    }
    return 25;
  }

  renderIconLeft() {
    const { back, iconLeft } = this.props;
    if (iconLeft) {
      return iconLeft;
    } else if (back) {
      return Platform.OS === 'android' ? 'md-arrow-back' : 'ios-arrow-back';
    }
    return 'ios-menu';
  }

  renderLeft() {
    const { componentLeft, color } = this.props;
    if (componentLeft) {
      return componentLeft;
    }
    if (Platform.OS === 'android' && Platform.Version >= 21) {
      return (
        <TouchableNativeFeedback
          onPress={() => this.actionLeft()}
          background={TouchableNativeFeedback.Ripple('#ccc', true)}
        >
          <View
            style={{
              width: 100,
              height: 50,
              alignItems: 'center',
              justifyContent: 'center',
              position: 'absolute',
              left: 0,
              flexDirection: 'row',
              zIndex: 999,
              backgroundColor: 'transparent'
            }}
          >
            <View
              style={{
                width: 50,
                height: 50,
                alignItems: 'center',
                justifyContent: 'center',
              }}
            >
              <IconIOS
                size={30}
                name={this.renderIconLeft()}
                style={{ color: color || '#fff' }}
              />
            </View>
            <View
              style={{
                width: 50,
                height: 50,
                alignItems: 'center',
                justifyContent: 'center',
              }} />
          </View>
        </TouchableNativeFeedback>
      );
    }
    return (
      <TouchableOpacity
        onPress={() => this.actionLeft()}
        style={{
          width: 100,
          height: 50,
          alignItems: 'center',
          justifyContent: 'center',
          position: 'absolute',
          left: 0,
          flexDirection: 'row',
          zIndex: 999,
          backgroundColor: 'transparent'
        }}
      >
        <View
          style={{
            width: 50,
            height: 50,
            alignItems: 'center',
            justifyContent: 'center',
          }}>
          <IconIOS
            size={30}
            name={this.renderIconLeft()}
            style={{ color: color || '#fff' }}
          />
        </View>
        <View
          style={{
            width: 50,
            height: 50,
            alignItems: 'center',
            justifyContent: 'center',
          }} />
      </TouchableOpacity>
    );
  }

  renderCenter() {
    const { componentCenter, color, styleTextCenter, styleCenter } = this.props;
    const { title } = this.state;
    const titleHeader = title;
    if (componentCenter) {
      return componentCenter;
    }
    return (
      <View
        style={[{
          justifyContent: 'center',
          alignItems: 'flex-start',
          flex: 1,
          paddingLeft: 50,
          backgroundColor: 'transparent'
        }, styleCenter]}
        pointerEvents="none"
      >
        <Text
          numberOfLines={2}
          style={[{
            color: color || '#fff',
            fontSize: 18,
            backgroundColor: 'transparent',
            textAlign: 'center'
          }, styleTextCenter]}>
          {titleHeader}
        </Text>
      </View>
    );
  }

  renderRight() {
    const { componentRight } = this.props;
    if (componentRight) {
      return componentRight;
    }
    return null;
  }

  render() {
    const { shadow, backgroundColor } = this.props;
    const { disable } = this.state;
    let shadowStyle = null;
    if (shadow) {
      shadowStyle = {
        elevation: 5,
        shadowOffset: {
          width: 0,
          height: 5,
        },
        shadowRadius: 5,
        shadowOpacity: 0.3,
        zIndex: 9
      };
    }
    if (disable) {
      return null;
    }
    return (
      <View
        style={[{
          paddingTop: this.getPaddingHeader(),
          backgroundColor: backgroundColor || '#387be0'
        }, shadowStyle]}
      >
        <View style={{
          height: 50,
          flexDirection: 'row',
        }}>
          {this.renderLeft()}
          {this.renderCenter()}
          {this.renderRight()}
        </View>
      </View>
    );
  }
}
