import React, { PureComponent } from 'react'; /* eslint-disable-line */
import { View, TextInput, Platform, TouchableOpacity, Keyboard } from 'react-native'; /* eslint-disable-line */
import IconIOS from 'react-native-vector-icons/Ionicons';

export default class InputSearch extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      value: '',
    };
  }

  onChangeText(text) {
    this.setState({
      value: text
    });
    this.props.onChangeText(text);
  }

  onClearTextInput() {
    this.input.clear();
    this.onChangeText('');
    Keyboard.dismiss();
  }

  onDone(arr) {
    this.props.onDone && this.props.onDone(arr);
  }

  componentLeft() {
    const { componentLeft } = this.props;
    if (componentLeft) {
      return componentLeft;
    }
    return null;
  }

  componentRight() {
    const { componentRight } = this.props;
    if (componentRight) {
      return componentRight;
    }
    return null;
  }

  render() {
    const { value } = this.state;
    const { style, } = this.props;
    return (
      <View >
        <View
          style={[{
            padding: 10,
            backgroundColor: '#f9f9f9',
            flexDirection: 'row',
            alignItems: 'center'
          }, style]}
        >
          {this.componentLeft()}
          <View
            style={{
              flexDirection: 'row',
              borderRadius: 5,
              alignItems: 'center',
              justifyContent: 'center',
              backgroundColor: '#f2f2f2',
              flex: 1
            }}
          >
            <IconIOS
              name="ios-search"
              color="#555"
              size={28}
              style={{
                marginLeft: 10,
                marginHorizontal: 5,
                backgroundColor: 'transparent'
              }}
            />
            <TextInput
              style={{
                height: 40,
                padding: 5,
                flex: 1,
                backgroundColor: 'transparent'
              }}
              ref={input => { this.input = input; }}
              clearButtonMode={'while-editing'}
              placeholder={'Tìm kiếm.....'}
              autoCorrect={false}
              autoCapitalize={'none'}
              returnKeyType="done"
              underlineColorAndroid="transparent"
              onChangeText={(text) => this.onChangeText(text)}
            />
            {
              value && Platform.OS === 'android' ? (
                <TouchableOpacity
                  style={{
                    height: 40,
                    width: 40,
                    alignItems: 'center',
                    justifyContent: 'center',
                  }}
                  onPress={() => {
                    this.onClearTextInput();
                  }}
                >
                  <IconIOS
                    name={'ios-close'}
                    size={25}
                    color={'#888'}
                  />
                </TouchableOpacity>
              ) : null
            }
          </View>
          {this.componentRight()}
        </View>
      </View>
    );
  }
}
